# src

* [src package](src.md)
  * [Subpackages](src.md#subpackages)
    * [src.providers package](src.providers.md)
      * [Submodules](src.providers.md#submodules)
      * [src.providers.google module](src.providers.md#module-src.providers.google)
      * [Module contents](src.providers.md#module-src.providers)
  * [Submodules](src.md#submodules)
  * [src.constants module](src.md#module-src.constants)
  * [src.decorators module](src.md#module-src.decorators)
    * [`callback()`](src.md#src.decorators.callback)
  * [src.errors module](src.md#module-src.errors)
    * [`ObscureException`](src.md#src.errors.ObscureException)
    * [`ObscureHttpResponse()`](src.md#src.errors.ObscureHttpResponse)
  * [src.jwt_helpers module](src.md#module-src.jwt_helpers)
    * [`calculate_expiration()`](src.md#src.jwt_helpers.calculate_expiration)
    * [`is_refresh_token_expired()`](src.md#src.jwt_helpers.is_refresh_token_expired)
    * [`set_cookies()`](src.md#src.jwt_helpers.set_cookies)
  * [src.provider module](src.md#module-src.provider)
    * [`OAuth2Provider`](src.md#src.provider.OAuth2Provider)
      * [`OAuth2Provider.extract_profile()`](src.md#src.provider.OAuth2Provider.extract_profile)
      * [`OAuth2Provider.fetch_profile()`](src.md#src.provider.OAuth2Provider.fetch_profile)
      * [`OAuth2Provider.get_authorization_url()`](src.md#src.provider.OAuth2Provider.get_authorization_url)
      * [`OAuth2Provider.get_callback_url()`](src.md#src.provider.OAuth2Provider.get_callback_url)
      * [`OAuth2Provider.get_oauth2_token()`](src.md#src.provider.OAuth2Provider.get_oauth2_token)
      * [`OAuth2Provider.timeout`](src.md#src.provider.OAuth2Provider.timeout)
  * [src.queries module](src.md#module-src.queries)
    * [`OAuth2LinksProvider`](src.md#src.queries.OAuth2LinksProvider)
    * [`OAuth2LinksProviderMetaclass`](src.md#src.queries.OAuth2LinksProviderMetaclass)
    * [`OAuth2LinksQuery`](src.md#src.queries.OAuth2LinksQuery)
      * [`OAuth2LinksQuery.o_auth2_links`](src.md#src.queries.OAuth2LinksQuery.o_auth2_links)
      * [`OAuth2LinksQuery.resolve_o_auth2_links()`](src.md#src.queries.OAuth2LinksQuery.resolve_o_auth2_links)
  * [src.state_manager module](src.md#module-src.state_manager)
    * [`OAuth2StateManager`](src.md#src.state_manager.OAuth2StateManager)
  * [Module contents](src.md#module-src)
